Contributing
============

Contributions are welcome from the community. Questions can be asked on the
[issues page][1]. Before creating a new issue, please take a moment to search
and make sure a similar issue does not already exist. If one does exist, you
can comment (most simply even with just a `:+1:`) to show your support for that
issue.

If you have direct contributions you would like considered for incorporation
into the project you can [fork this repository][2] and
[submit a pull request][3] for review.

[1]: https://code.usgs.gov/esc/SKHASH/issues
[2]: https://docs.gitlab.com/ee/user/project/repository/forking_workflow.html#create-a-fork
[3]: https://docs.gitlab.com/ee/user/project/merge_requests/creating_merge_requests.html
